@@ -11,6 +11,7 @@ from aiohttp import http
 from aiohttp.client import ClientSession
 from aiohttp.client_reqrep import ClientResponse
 from ddt import ddt, data
+from pkg_resources import parse_version
 
 try:
     from aiohttp.errors import (
@@ -117,7 +118,7 @@ class AIOResponsesTestCase(AsyncTestCase):
         self.assertEqual(cm.exception.message, http.RESPONSES[400][0])
 
     @aioresponses()
-    @skipIf(condition=AIOHTTP_VERSION < '3.4.0',
+    @skipIf(condition=AIOHTTP_VERSION < parse_version('3.4.0'),
             reason='aiohttp<3.4.0 does not support raise_for_status '
                    'arguments for requests')
     async def test_request_raise_for_status(self, m):
@@ -165,6 +166,26 @@ class AIOResponsesTestCase(AsyncTestCase):
         content = await resp.content.read(2)
         self.assertEqual(content, b'st')
 
+    @aioresponses()
+    async def test_binary_body(self, m):
+        body = b'Invalid utf-8: \x95\x00\x85'
+        m.get(self.url, body=body)
+        resp = await self.session.get(self.url)
+        content = await resp.read()
+        self.assertEqual(content, body)
+
+    @aioresponses()
+    async def test_binary_body_via_callback(self, m):
+        body = b'\x00\x01\x02\x80\x81\x82\x83\x84\x85'
+
+        def callback(url, **kwargs):
+            return CallbackResult(body=body)
+
+        m.get(self.url, callback=callback)
+        resp = await self.session.get(self.url)
+        content = await resp.read()
+        self.assertEqual(content, body)
+
     async def test_mocking_as_context_manager(self):
         with aioresponses() as aiomock:
             aiomock.add(self.url, payload={'foo': 'bar'})
@@ -250,6 +271,15 @@ class AIOResponsesTestCase(AsyncTestCase):
             with self.assertRaises(HttpProcessingError):
                 await self.session.get(url)
 
+            callback_called = asyncio.Event()
+            url = 'http://example.com/HttpProcessingError'
+            aiomock.get(url, exception=HttpProcessingError(message='foo'),
+                        callback=lambda *_, **__: callback_called.set())
+            with self.assertRaises(HttpProcessingError):
+                await self.session.get(url)
+            
+            await callback_called.wait()
+
     async def test_multiple_requests(self):
         """Ensure that requests are saved the way they would have been sent."""
         with aioresponses() as m:
@@ -524,7 +554,7 @@ class AIOResponsesRaiseForStatusSessionTestCase(AsyncTestCase):
         self.assertEqual(cm.exception.message, http.RESPONSES[400][0])
 
     @aioresponses()
-    @skipIf(condition=AIOHTTP_VERSION < '3.4.0',
+    @skipIf(condition=AIOHTTP_VERSION < parse_version('3.4.0'),
             reason='aiohttp<3.4.0 does not support raise_for_status '
                    'arguments for requests')
     async def test_do_not_raise_for_status(self, m):
@@ -602,7 +632,7 @@ class AIOResponseRedirectTest(AsyncTestCase):
         self.assertEqual(str(response.url), self.url)
 
     @aioresponses()
-    @skipIf(condition=AIOHTTP_VERSION < '3.1.0',
+    @skipIf(condition=AIOHTTP_VERSION < parse_version('3.1.0'),
             reason='aiohttp<3.1.0 does not add request info on response')
     async def test_request_info(self, rsps):
         rsps.get(self.url, status=200)
@@ -614,7 +644,7 @@ class AIOResponseRedirectTest(AsyncTestCase):
         assert request_info.headers == {}
 
     @aioresponses()
-    @skipIf(condition=AIOHTTP_VERSION < '3.1.0',
+    @skipIf(condition=AIOHTTP_VERSION < parse_version('3.1.0'),
             reason='aiohttp<3.1.0 does not add request info on response')
     async def test_request_info_with_original_request_headers(self, rsps):
         headers = {"Authorization": "Bearer access-token"}
